#
# spec file for package obs-service-cargo
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obs-service-cargo
Summary:        OBS Source Service and utilities for Rust software packaging
License:        MPL-2.0
Group:          Development/Tools/Building
# Repository name subject to change
URL:            https://github.com/openSUSE-Rust/%{name}
Version:        5.1.0
Release:        1.1
Source0:        https://github.com/openSUSE-Rust/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libzstd)
# Version with fixed vendor filterer
Requires:       cargo-vendor-filterer >= 0.5.16
Requires:       (cargo or rustup)
# At 0.6.0, vendor was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_vendor
Obsoletes:      obs-service-cargo_vendor
Provides:       obs-service-cargo_vendor = %{version}
# At 0.7.0, audit was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_audit
Obsoletes:      obs-service-cargo_audit
Provides:       obs-service-cargo_audit = %{version}

%description
This is an OBS Source Service that contains two main utilities:
- OBS Service Cargo Vendor
- OBS Service Cargo Vendor Home Registry

This vendors and audits dependencies for packaging Rust software.

See the <https://github.com/openSUSE-Rust/obs-service-cargo/blob/master/README.md>
for full documentation.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
install -m0755 %{_builddir}/%{name}-%{version}/target/release/cargo_vendor %{buildroot}%{_prefix}/lib/obs/service
# This will get removed in the future.
install -m0755 %{_builddir}/%{name}-%{version}/target/release/cargo_audit  %{buildroot}%{_prefix}/lib/obs/service
install -m0644 cargo_vendor.service %{buildroot}%{_prefix}/lib/obs/service

%files
%defattr(-,root,root)
%doc README.md CHANGELOG.md CONTRIBUTING.md CODE_OF_CONDUCT.md
%license LICENSE
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service

%changelog
* Mon Apr 14 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.0:
  * Bump toolchain version to stable
  * Apply fix for clippy error "double_ended_iterator_last"
  * Make `segments` mutable in testing code
  * Update Cargo.lock
* Fri Mar  7 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.0.0:
  * Update MSRV to 1.85 and Rust edition to 2024
  * Update Cargo.lock
  * revert: trying to patch gix-worktree-state
  * refactor code for Rust edition 2024
* Mon Feb 10 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update vendored dependencies.
  * This also updates Cargo.lock so openssl is set to version
    "0.10.70". Avoids CVE-2025-24898 alerts. This CVE does not
    really affect us.
* Thu Jan 30 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.5.0:
  * test: update sources for roast.
  * security: update gix-worktree-state to 0.17.0
  * fix(doc): missing last double quote now added.
  * toolchain: add most used components for rust development
- Set rust toolchain to version 1.83
* Fri Dec 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.4.1:
  * fix: avoid infinite recursion causing stack overflow
  * tests: add just to the test vendored files
* Thu Dec 19 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.4.0:
  * chore: apply clippy suggestions
  * improvement: ensure paths are handled. also output the hashes of lockfiles before and after.
  * fix: it should be using custom_root and not setup_workdir
  * fix tests
  * tests: from_str to from in PathBuf
  * chore: set MSRV to 1.83
  * chore: update Cargo.lock
  * tests: add tokenizers for registry method testing
* Mon Dec  9 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.3.6:
  * improvement: ensure to communicate well to users when a "No space left on device occurs"
- Update vendored dependencies.
* Wed Nov 27 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.3.5:
  * fix: finally added the alias. 🫠
  * chore: update roast to 5.1.7. update other dependencies as well.
* Sun Nov 17 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.3.3:
  * fix: let cargo just put where the vendor directory is by default which is the curdir
* Sun Nov 17 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.3.2:
  * fix: updating specific crates was not properly implemented. now resolved.
* Sun Nov 17 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.3.1:
  * fix: correctly use setup_workdir and custom_root
  * fix: resolve location for the vendor directory
  * remove: it's not our bug. using `--target` for multiple triples now removed
  * fix: do not canonicalize in first_manifest
  * fix: remove the wrongly used else-clause
  * improvements: ensure that the additional manifest paths ends with `Cargo.toml`
  * docs: update docs to include the new feature with feature additions
  * improvements: parent path of Cargo.toml files are now set as current directory when invoking commands
* Sat Nov 16 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.2.2:
  * fix: add more info
  * fix: add warning
  * fix: ignore error when crate dependency does not exist for manifest path
  * update description
  * feat: update can now specify recursive or precise
  * fix: can now determine a member that uses a glob pattern
  * feat: add all target triples as no opt for cargo-fetch
  * docs(fix): if set to true
  * fix: correct error message for lockfiles
  * docs: replace underscore with dash
* Fri Nov  8 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.1.1:
  * Remove unnecessary if-elses
* Thu Nov  7 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.1.0:
  * tests: readd tests for lockfile hash comparisons between update false and update true
  * fix: this should pass a valid manifest path-like-string
  * improvements: use new dependency detection and return properly
  * fix: this if-else condition is stupid. fixed
  * misc: update warning message and remove comment
  * docs: update README explaining how respect-lockfile behaves
  * improvements: fix issues with how we respect lockfile
  * docs: include respect-lockfile, and allowedvalue should be allowedvalues
  * improvements: introduce the new dependency detection
  * improvements: properly detect dependencies
  * improvements: adjust where we pass around the update variable
  * fix: reintroduce respect-lockfile flag
  * misc: make vendor have a separate registry as well
  * misc: move over the env initialisation to here
* Wed Nov  6 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.0.2:
  * refactor: check if all manifest needs to get vendored
  * refactor: properly cleanup directories and exit if there are actually no dependencies
  * docs: put the xml service to readme as well
  * chore: improve descriptions of each flag
  * deps: replace sha3 with sha2
  * fmt: fix spaces and tabs and parentheses
* Wed Nov  6 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.0.0:
  * update service description file
  * docs: improve explainer about lockfiles
  * fix: added trace feature
  * minor: check the else clause
  * improvements in the service file metadata
  * remove bulk-updater
  * refactor: This is a major refactor by combining home registry and vendor.
  * refactor: implemented cargo vendor
  * tests: update test suite in CI to conform with new code changes
  * fix: remove unnecessary if-else that broke the vendor logic
  * fix: again, vendor filterer does not support --locked
  * improvements + filterer fixes
  * fix: typoed a dash. it was an underscore
  * fix: rework where we put vendor
  * improvement: set env before everything for registry
  * improvement: improve messages
  * tests: add test of the output tarball
  * do tests in release mode
  * fix: change how custom root behaves on "regular" vendor
  * ci(fix): properly alias the tests instead to run tests in release mode
  * fix: create the paths first
  * fix: 🎉 squashed all bugs and ready for user testing
  * rename field from manifest-paths to manifest-path
  * docs: update service file
  * add one more test case
  * docs: enhance README
  * remove unstable-doc feature
  * docs: remove cargo_audit in the examples
  * docs: fix typo
  * docs: spelling plus make alias clear
  * remove cargo_audit.service. not needed anymore
  * fix: if-else to check if it is a workspace or not has been corrected
  * docs: update README. outdated statement removed
  * docs: update README
  * docs: explain how cargotoml behaviour works between methods
  * tests: test bonk that it really has no dependencies
  * tests: adjust if-else as without it will lead to failure since we are testing that raw cannot find a vendor tarball
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 3.6.1:
  * docs: improve explainer about lockfiles
  * update service description file
  * ensure lockfile creation
  * minor: small refactor in generate_lockfile and vendor
  * fix: forgot to use clap::ArgAction::Set. now finally added
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 3.6.0:
  * chore: release v3.6.0
  * fix: used a different cargotoml. now using the correct one for flux
  * find cargo vendor filterer by exporting PATH in container
  * add forgotten run
  * use traced test
  * tests: add tests for cargotoml flag
  * tests: lessen verbosity and rename nonexistent function to existing one
  * tests: add tests for unfiltered and filtered option
  * chore: update manifest and dependencies
  * refactor: migrates almost all logic to libroast. 🎉
  * fix: rectify mismatched types
  * chore: remove dependencies since libroast is used internally
  * add COC and CONTRIBUTING
  * update changelog
  * chore: release v3.5.4
  * Bump rustsec to fix #99 and quick-xml because why not
  * chore: release v3.5.2
  * feat: add versioned-dirs flag
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 3.5.4
  * Bump rustsec to fix #99 and quick-xml because why not
  * feat: add versioned-dirs flag
  * Note: This is a BREAKING CHANGE
  * refactor: migrate some ideas and move the compression logic to roast internally
- Set version of vendor-filterer to >= 0.5.16. Contains a fix for the versioned-dirs
* Fri Oct 18 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 3.3.3:
  * Use versioned-dirs only for unfiltered vendoring, as cargo-vendor-filterer does not support this flag yet
  * crates: get libroast dep from crates.io
  * feat: support uncompressed tarballs or with `.tar` extension
  * cli: improve description
  * cargo: update lockfile and bump crate versions
  * fix changelog
  * fix: properly set which version to set in the manifest
* Sat Oct 12 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 2.0.0
  * refactor: successful move to use libroast
  * minor: add `--versioned-dirs` flag
* Mon Sep 23 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update vendor.tar.zst: gix-path improper path resolution
  (bsc#1230688 CVE-2024-45405).
* Tue Sep  3 2024 Gordon Leung <pirateclip@protonmail.com>
- Update vendored deps to resolve boo#1230083
* Mon Jul 29 2024 Gordon Leung <pirateclip@protonmail.com>
- Bump constraints, zsystems still keeps failing due to OOM
* Tue Jun 25 2024 Gordon Leung <pirateclip@protonmail.com>
- Add _constraints to stop s390x out of memory build fails
* Tue Jun 11 2024 Gordon Leung <pirateclip@protonmail.com>
- Fix build failures caused by the topmost folder being renamed
  from obs-service-cargo_vendor to obs-service-cargo
* Thu Jun  6 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.6
  * Fix Clippy error and add Clippy CI
  * fix: vendor-filterer --all-features rather than --all-features=true
  * internet_points: Add Pi-Cla
  * 20240523 ensure to regenerate lockfiles if vendor set to false
  * doc: fix warning indicator
  * fix again warn indicator
* Thu May  2 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.2:
  * dependencies update
- Update resolves security incidents. I believe this does not really affect
  how obs-service-cargo behaves but for now, I just want to avoid the alerts.
* Sat Mar 30 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.1:
  * docs: update CHANGELOG
  * docs: add CONTRIBUTORS.md
  * cargo-vendor-filterer now supports --sync
* Sat Mar 23 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add cargo vendor-filterer as requirement.
- Set `filter` to true in _service file.
- Update vendored dependencies with filterer.
* Sat Mar  9 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.2.1:
  * Add experimental vendor_filterer support
* Sat Mar  2 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.1.0:
  * make tarballs reproducible
* Sun Jan 14 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 1.0.0:
  * No code change *
* Sun Dec 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.9.0:
  * No code change *
* Mon Dec 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.21:
  * Improve errors with outpath
* Thu Dec  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.20:
  * added bz2 mime
  * add fixes to make bz2 mime supported
* Tue Dec  5 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.18:
  * (de)compress: add Bz2 compression
  * refactor return types and initial boilerplate for bz2 compress
  * nitpick. slight refactor because Ok(()) looks yuck in some contexts
  * it should be `--output` if we want to download a file
* Fri Nov 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.15:
  * fix: we also include build_dependencies
  * test: add VBox-Starter in runtests.sh
  * fix: check also the targets section
  * misc: nitpick. remove small space
  * fix typo
  * docs: put warning on README
* Tue Nov 21 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.12:
  * improv: reintroduced tag in README
  * Add tagging
  * docs: add possible vendor failures in README
  * make cargotoml usage clearer
* Sat Nov 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.10:
  * docs: update README
  * move lints to configuration manifest
  * an improvement of commit 24aaa0056
  * configure rust version and toolchain"
  * check if there are lockfiles from aforementioned manifest paths
  * fix: check if dependencies section is empty or not
  * misc: remove redundant messages
  * improvement: better handling on when and when not to vendor
* Fri Nov 17 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove cargo_config. Part of vendored tarball now
- Update to 0.8.9:
  * dummy determine the path of the lockfile
* Fri Nov 17 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.8.8:
  * clippy: change match to if let
  * docs: add dependencies section in the README
  * fix: just warn and don't return an error
  * fix: hasdeps should inherit should_vendor value
  * fix: also join the paths from `prjdir`
  * Remove tags, fix multitoml vendor, automatically add .cargo/config
  * fix multi cargo issue
  * do not exit process when terminfo is not found.
- Disable update. Cargo cannot find glob crate when trying to update.
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.4:
  * fix: also check attempt to vendor if it is also a workspace
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.3:
  * misc: add stop sign in error message
  * improve error handling impl
  * fix: also make sure it really has no deps
  * utils: exit vendor step if no dependencies found
  * update README again
  * update README
  * docs: update README regarding the new flag
  * all: apply clippy lint suggestions
  * fix: also copy top-level folder if src is a directory
  * Rework of compression and vendoring to be clearer
  * Minor output improvements
  * fix: also copy top-level folder if src is a directory
  * update email address in manifest file
  * remove unused dead code
  * clippy: apply clippy suggestions
* Thu Oct 12 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.8.0:
  * audit is no-op and it is now part of vendor process.
  * cargo_audit binary will execute nothing now.
* Wed Oct 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.5:
  * globbed tar now supports lexicographical order
  * improved rustsec output
* Mon Oct  9 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.4:
  * fix: decompressed tarball may or may not have a top-level folder
* Sat Oct  7 2023 William Brown <william.brown@suse.com>
- Change obsoletes to not list a version as we obsolete all versions.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.3.
  * small fixes and changes
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.7.1. No changes.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.7.0:
  * refactor cargo vendor
  * feature audit
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Change to 0.6.0 release
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for obs-service-cargo. 0.6.0-alpha
